<?php
// Include necessary libraries or use autoloading
// For example, if using Composer
// require 'vendor/autoload.php';

// Define your app's secret key (the same used during registration)
$appSecret = 'ddfba34c-61c9-4eb0-9a4d-dc26b261696f';

// Get the raw POST data from the request
$data = json_decode(file_get_contents('php://input'), true);

// Verify the proof sent by Shopware
$expectedProof = hash_hmac('sha256', $data['shopId'] . $data['shopUrl'] . 'customaio', $appSecret);

// Check if the proof matches
if ($data['proof'] !== $expectedProof) {
    http_response_code(401);
    echo json_encode(['error' => 'Invalid proof']);
    exit;
}

// If proof is valid, you can process the data further
$shopId = $data['shopId'];
$shopUrl = $data['shopUrl'];
$apiKey = $data['apiKey']; // API key sent by Shopware
$secretKey = $data['secretKey']; // Secret key sent by Shopware

// Store the API credentials and shop details securely
// You can use a database or any secure storage method
// Example using PDO for MySQL (modify according to your database setup)
try {
    $pdo = new PDO('mysql:host=your_host;dbname=your_db', 'username', 'password');
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Prepare the SQL statement to insert the shop details
    $stmt = $pdo->prepare("INSERT INTO registered_shops (shop_id, shop_url, api_key, secret_key) VALUES (?, ?, ?, ?)");
    $stmt->execute([$shopId, $shopUrl, $apiKey, $secretKey]);

    // Send a successful response back to Shopware
    echo json_encode(['status' => 'success', 'message' => 'Registration confirmed successfully.']);
} catch (PDOException $e) {
    // Handle any database errors
    http_response_code(500);
    echo json_encode(['error' => 'Database error: ' . $e->getMessage()]);
}
